<?php

namespace AustraliaPost\Extensions\Business\API\Wrapper\Connectors;

class E_Parcel_Connector extends Abstract_Connector {

	const API_URL_TEST_MODE = 'https://digitalapi.auspost.com.au/test/shipping/v1';
	const API_URL_LIVE_MODE = 'https://digitalapi.auspost.com.au/shipping/v1';

	private $test_mode = true;

	private $username;
	private $password;
	private $account_number;



	/**
	 * Connector constructor.
	 *
	 * @param string $username
	 * @param string $password
	 * @param string $account_number
	 */
	public function __construct( $username, $password, $account_number )
	{
		$this->username       = $username;
		$this->password       = $password;
		$this->account_number = $account_number;
	}

	protected function getHeaders() {
		return [
			'Accept'         => 'application/json',
			'Content-Type'   => 'application/json',
			'Account-Number' => $this->account_number,
			'Authorization'  => sprintf('Basic %s', $this->getAuthString()),
			'Partner-ID'     => self::PARTNER_ID
		];
	}

	private function getAuthString()
	{
		return base64_encode(sprintf('%s:%s', $this->username, $this->password));
	}

	protected function testMode()
	{
		return  $this->test_mode;
	}

	public function getAccountNumber() {
		return $this->account_number;
	}

	public function apiUrl() {
		return  (true === $this->testMode())? self::API_URL_TEST_MODE: self::API_URL_LIVE_MODE;
	}

	/**
	 * @return string
	 */
	public function getUsername() {
		return $this->username;
	}

	/**
	 * @param string $username
	 *
	 * @return E_Parcel_Connector
	 */
	public function setUsername( $username ) {
		$this->username = $username;

		return $this;
	}

	/**
	 * @return string
	 */
	public function getPassword() {
		return $this->password;
	}

	/**
	 * @param string $password
	 *
	 * @return E_Parcel_Connector
	 */
	public function setPassword( $password ) {
		$this->password = $password;

		return $this;
	}


}
